@@ -2,20 +2,21 @@
 #'
 #' @param contr \code{pmxClass} controller
 #' @param name \code{character} The report name
-#' @param format \code{character} the result type, can be \cr
+#' @param output \code{character} the result type, can be \cr
 #' a standalone directory of plots or a report document as defined in the template \cr
 #' (pdf, docx,..) ,or both
 #' @param template \code{character} ggPMX predefined template or the
-#' path to a custom rmarkdwon template. \cr
+#' path to a custom rmarkdown template. \cr
 #' Use \code{\link{pmx_report_template}} to get the list
 #' of available templates
 
-#' @param save_dir Output directory.  A directory to write the results files to
+#' @param save_dir Output directory. A directory to write the results files to
+#' @param plots_subdir Output folder name, ggpmx_GOF by default
 #' @param footnote \code{logical}  TRUE to add a footnote to the generated plots. The default footnote is to add \cr
 #' the path where the plot is saved.
 #' @param edit \code{logical}  TRUE to edit the template immediately
-#' @param extension \code{character} The output document format. By default, a word report is generated. \cr
-#'  User can specify one or more formats from c("word","pdf","html","all"). extnestion "all" to generate all formats.
+#' @param format \code{character} The output document format. By default, a word report is generated. \cr
+#'  User can specify one or more formats from c("word","pdf","html","all"). format "all" to generate all formats.
 #' @param title \code{character} report title (optional)
 #' @param ... extra parameters depending in the template used
 #' @export
@@ -31,11 +32,12 @@ pmx_report <-
   function(contr,
              name,
              save_dir,
-             format = c("both", "plots", "report"),
+             plots_subdir = "ggpmx_GOF",
+             output = c("all", "plots", "report"),
              template = "standing",
-             footnote = format == "both",
+             footnote = output == "all",
              edit = FALSE,
-             extension = NULL,
+             format = NULL,
              title,
              ...) {
 
@@ -46,14 +48,17 @@ pmx_report <-
       is.character(template),
       length(template) == 1L
     )
+    
+    output <- match.arg(output)
+    if (missing(format) || is.null(format)) format <- "word"
+    if (sum(format %in% c("word","pdf","html","all")) == 0) {
+      stop("format must be one or more of the following formats:\nc(\"word\",\"pdf\",\"html\",\"all\")", call.=FALSE)
+    }
 
-    format <- match.arg(format)
-    if (missing(extension) || is.null(extension)) extension <- "word"
-
-    if (!"all" %in% extension) {
-      extension <- sprintf("%s_document", extension)
+    if (!"all" %in% format) {
+      format <- sprintf("%s_document", format)
     } else {
-      extension <- "all"
+      format <- "all"
     }
     on.exit({
       remove_temp_files(contr$save_dir)
@@ -70,11 +75,11 @@ pmx_report <-
 
     contr$footnote <- footnote
     res <- pmx_draft(contr, name, template, edit = FALSE)
-    standalone <- format %in% c("plots", "both")
+    standalone <- output %in% c("plots", "all")
     clean <- !standalone
     old_fig_process <- knitr::opts_chunk$get("fig.process")
 
-    out_ <- file.path(contr$save_dir, "ggpmx_GOF")
+    out_ <- file.path(contr$save_dir, plots_subdir)
 
     rm_dir(out_)
 
@@ -106,7 +111,7 @@ pmx_report <-
       res,
       params = params,
       envir = envir,
-      output_format = extension,
+      output_format = format,
       output_dir = save_dir,
       clean = clean,
       quiet = TRUE
@@ -121,10 +126,10 @@ pmx_report <-
     rm_dir(in_)
 
     if (!clean) {
-      ## create_ggpmx_gof(ctr$save_dir, name)
-      remove_reports(format, contr$save_dir)
+      ## create_ggpmx_gof(ctr$save_dir, name, plots_subdir)
+      remove_reports(output, contr$save_dir)
     }
-    if (format == "report") rm_dir(out_)
+    if (output == "report") rm_dir(out_)
   }
 
 
@@ -162,18 +167,56 @@ pmx_draft <- function(ctr, name, template, edit) {
   }
 
   if (file.exists(template)) {
-    template_path <- system.file(
-      "rmarkdown", "templates",
-      ifelse(ctr$config$hasNpd,"npd", "standing"),
-      package = "ggPMX"
-    )
-    temp_dir <- tempdir()
-    invisible(file.copy(template_path, temp_dir, recursive = TRUE,
-                        copy.mode=FALSE))
-    dest_temp <- file.path(temp_dir, "standing", "skeleton", "skeleton.Rmd")
-    invisible(file.copy(template, dest_temp, overwrite = TRUE,
-                        copy.mode=FALSE))
+    ggPMX_dir <- system.file(package = "ggPMX")
+
+    standing_file <- system.file(
+      "rmarkdown",
+      "templates",
+      ifelse(
+        ctr$config$hasNpd &
+          dir.exists(file.path(ggPMX_dir, "rmarkdown", "templates", "npd")),
+        "npd",
+        "standing"
+      ),
+      package="ggPMX")
+
+    # Defining template and skeleton temporary subdirs, creating if missing
+    # tempdir includes random subdir, so it is new for each run
+    temp_dir <- file.path(tempdir(), paste0(sample(letters, 9), collapse=""))
+
     template_dir <- file.path(temp_dir, "standing")
+    if (!dir.exists(template_dir)) {
+      invisible(dir.create(template_dir, recursive=TRUE))
+    }
+
+    skeleton_dir <- file.path(template_dir, "skeleton")
+    if (!dir.exists(skeleton_dir)) {
+      invisible(dir.create(skeleton_dir, recursive=TRUE))
+    }
+
+    # Copying template and skeleton files to subdirectories
+    invisible({
+      file.copy(
+        from = file.path(standing_file, "template.yaml"),
+        to = template_dir,
+        overwrite = TRUE,
+        recursive = TRUE
+      )
+      # Determine source of template file (variable may be a directory or a file)
+      template_source <-
+        if(grepl("\\.[A-z]{2,}$", template)) {
+          template
+        } else {
+          file.path(template, "skeleton", "skeleton.Rmd")
+        }
+
+      file.copy(
+        from = template_source,
+        to = file.path(skeleton_dir, "skeleton.Rmd"),
+        overwrite = TRUE
+      )
+    })
+
     res <- draft(
       template_file,
       template = template_dir,
@@ -205,19 +248,20 @@ remove_temp_files <-
     invisible(file.remove(temp_files))
   }
 
-remove_reports <- function(format, save_dir) {
-  if (format == "plots") {
-    invisible(file.remove(list.files(
-      pattern = "(.pdf|.docx|Rmd)$",
-      path = save_dir, full.names = TRUE
+
+remove_reports <- function(output, save_dir) {
+  if (output == "plots") {
+    invisible(file.remove(
+      list.files(pattern="(.pdf|.docx|Rmd)$", path=save_dir, full.names=TRUE
     )))
   }
 }
 
-create_ggpmx_gof <- function(save_dir, name) {
+
+create_ggpmx_gof <- function(save_dir, name, plots_subdir = "ggpmx_GOF") {
   plot_dir <- sprintf("%s_files", name)
   if (dir.exists(file.path(save_dir, plot_dir))) {
-    out_ <- file.path(save_dir, "ggpmx_GOF")
+    out_ <- file.path(save_dir, plots_subdir)
     rm_dir(out_)
     dir.create(out_)
     in_ <- file.path(save_dir, plot_dir)
